Zero
====

.. raw:: html

   <svg xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns="http://www.w3.org/2000/svg" xmlns:xl="http://www.w3.org/1999/xlink" version="1.1" viewBox="270 351 28 28" width="130" height="130" style="text-align:center;display:block;">
     <defs/>
     <g id="Canvas_1" stroke-dasharray="none" fill="none" fill-opacity="1" stroke-opacity="1" stroke="none">
       <title>Canvas 1</title>
       <g id="Canvas_1_Layer_1">
         <title>Layer 1</title>
         <g id="Graphic_7">
           <circle cx="284" cy="365" r="13.0000207727246" fill="black"/>
           <circle cx="284" cy="365" r="13.0000207727246" stroke="black" stroke-linecap="round" stroke-linejoin="round" stroke-width="1"/>
         </g>
       </g>
     </g>
   </svg>

.. include:: ../README.rst
   :start-after: __INCLUDE_0__
   :end-before: __INCLUDE_1__

.. _installation:

.. include:: ../README.rst
   :start-after: __INCLUDE_1__

.. toctree::
   :caption: NOTES
   :hidden:

   learn

.. toctree::
   :caption: API REFERENCE
   :hidden:

   reference/zero
   reference/data
   reference/hardware
   reference/nn
   reference/random

----

Indices and Tables
------------------

* :ref:`genindex`
* :ref:`modindex`
